Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

API Documentation

The full Rust API reference is generated from source code documentation using cargo doc.

Viewing API Docs

Build and view the API documentation locally:

# Build all crate docs
cargo doc --workspace --no-deps --open

# Or use the unified build script
bash scripts/build-docs.sh

When using scripts/build-docs.sh, the API docs are available at target/book/doc/.

Publishing Docs

The Docs GitHub Actions workflow builds the book and Rust API docs on pushes to main and on manual dispatch.

GitHub Pages deployment is enabled only when both of the following are true:

  • The repository Pages source is set to GitHub Actions
  • The repository variable ENABLE_GITHUB_PAGES_DOCS is set to true

The published site is available at https://tirea-ai.github.io/tirea/.

Crate Index

CrateDescriptionAPI Docs
tirea_stateCore state managementtirea_state
tirea_state_deriveDerive macrostirea_state_derive
tirea_contractShared contractstirea_contract
tirea_agentosAgent runtime & orchestrationtirea_agentos
tirea_store_adaptersPersistence adapterstirea_store_adapters
tirea_agentos_serverServer gatewaytirea_agentos_server
tireaUmbrella re-export cratetirea

Key Entry Points

tirea_state

tirea_contract

tirea_agentos